% Elaborato di Robotica Industriale
% M. Gritti e W. Spinelli
%
% MATLAB Function che descrive la cinematica inversa del robot planare a 2 link
%
%  y = cin_inversa(u)
%
% Parametri della Function
%

% Ingressi
% u(1) = X        : Ascissa dell'end-effector nello spazio operativo
% u(2) = Y        : Ordinta dell'end-effector nello spazio operativo
% u(3) = g        : Configurazione del robot:
%                    -1 : gomito alto
%                    +1 : gomito basso
% Uscite
% y(1)            : Posizione del link 1
% y(2)            : Posizione del link 2

function y = cin_inversa(u);

x = u(1);         % Ascissa dell'end-effector nello spazio operativo
y = u(2);         % Ordinta dell'end-effector nello spazio operativo

gom = u(3);       % Configurazione del robot (gomitoo alto/basso)
a = u(4);         % Lunghezza dei link (supposti uguali)

% Calcolo di q2

c2 = (x^2 + y^2 - 2*a^2) / (2*a^2);
s2 = gom * sqrt(1 - c2^2);
q2 = atan2(s2,c2);

% Calcolo di q1

c1 = ((a + a*c2)*x + a*s2*y) / (x^2 + y^2);
s1 = ((a + a*c2)*y - a*s2*x) / (x^2 + y^2);
q1 = atan2(s1,c1);

y = [q1 q2]';
